@@ -27,6 +27,7 @@
 #include <clutter/clutter.h>
 
 #include "window-tracker.h"
+#include "types.h"
 
 G_BEGIN_DECLS
 
@@ -70,6 +71,12 @@ GType xfdashboard_stage_get_type(void); /* G_GNUC_CONST; */
 
 ClutterActor* xfdashboard_stage_new(void);
 
+XfdashboardStageBackgroundImageType xfdashboard_stage_get_background_image_type(XfdashboardStage *self);
+void xfdashboard_stage_set_background_image_type(XfdashboardStage *self, XfdashboardStageBackgroundImageType inType);
+
+ClutterColor* xfdashboard_stage_get_background_color(XfdashboardStage *self);
+void xfdashboard_stage_set_background_color(XfdashboardStage *self, const ClutterColor *inColor);
+
 void xfdashboard_stage_show_notification(XfdashboardStage *self, const gchar *inIconName, const gchar *inText);
 
 G_END_DECLS
